@@ -23,6 +23,35 @@ function is_api_endpoint() {
     return false;
 }
 
+// Function to validate CSRF token
+function validate_csrf_token() {
+    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
+        $csrf_token = null;
+        
+        // Check for CSRF token in POST data first
+        if (!empty($_POST['csrf_token'])) {
+            $csrf_token = $_POST['csrf_token'];
+        }
+        // For API endpoints, check X-CSRF-Token header
+        elseif (!empty($_SERVER['HTTP_X_CSRF_TOKEN'])) {
+            $csrf_token = $_SERVER['HTTP_X_CSRF_TOKEN'];
+        }
+        
+        if (empty($_SESSION['csrf_token']) || empty($csrf_token)) {
+            return false;
+        }
+        
+        // Use hash_equals to prevent timing attacks
+        return hash_equals($_SESSION['csrf_token'], $csrf_token);
+    }
+    return true; // GET requests don't need CSRF validation
+}
+
+// Function to get CSRF token for forms
+function get_csrf_token() {
+    return isset($_SESSION['csrf_token']) ? $_SESSION['csrf_token'] : '';
+}
+
 $SecMan = new security_wrapper();
 $NetInfo = new network_info();
 $SecManager = new security_manager();
@@ -43,13 +72,20 @@ if ($blocked_info) {
 if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
     $results = $SecMan->pam_login($_POST["user"], $_POST["password"]);
     if ( $results == TRUE ) {
-        // Successful login
+        // Successful login - regenerate session ID to prevent session fixation
+        session_regenerate_id(true);
+        
         define('AUTH_USER',$_POST["user"]);
         define('HOME_DIR', $SecMan->get_home_dir($_POST["user"]));
         $user_ip = $NetInfo->get_client_ip();
         $nonce = $SecMan->create_nonce($_POST['user'], $user_ip,NONCE_SALT);
         $_SESSION['nonce'] = $nonce;
         
+        // Generate CSRF token for this session
+        if (empty($_SESSION['csrf_token'])) {
+            $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
+        }
+        
         // Record successful login and clear failed attempts
         $SecManager->record_successful_login($user_ip);
         
@@ -90,6 +126,11 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
         $user_ip = $NetInfo->get_client_ip();
         $nonce = $SecMan->create_nonce($nonce_check['user'], $user_ip,NONCE_SALT);
         $_SESSION['nonce'] = $nonce;
+        
+        // Generate CSRF token for this session if not already set
+        if (empty($_SESSION['csrf_token'])) {
+            $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
+        }
     } else {
         print_r($nonce_check);
         die();
@@ -128,4 +169,22 @@ if ( isset($_REQUEST['whp-action']) && $_REQUEST['whp-action'] == 'logout') {
 // Check page permissions for authenticated users
 if (defined('AUTH_USER') && $_SERVER['SCRIPT_FILENAME'] == '/docker/whp/web/index.php') {
     check_page_permission();
+}
+
+// CSRF Protection for all POST requests (except login)
+if (defined('AUTH_USER') && $_SERVER['REQUEST_METHOD'] === 'POST') {
+    // Skip CSRF check for login form
+    if (!isset($_POST['user']) && !isset($_POST['password'])) {
+        if (!validate_csrf_token()) {
+            if (is_api_endpoint()) {
+                header('HTTP/1.1 403 Forbidden');
+                header('Content-Type: application/json');
+                echo json_encode(['status' => 'error', 'message' => 'CSRF token validation failed']);
+                exit;
+            } else {
+                header('HTTP/1.1 403 Forbidden');
+                die('CSRF token validation failed. Please try again.');
+            }
+        }
+    }
 }
\ No newline at end of file
