@@ -736,7 +736,7 @@ function testTarget(targetId) {
         headers: {
             'Content-Type': 'application/x-www-form-urlencoded',
         },
-        body: `action=test_target&target_id=${targetId}&nonce=<?php echo $_SESSION['nonce']; ?>`
+        body: `action=test_target&target_id=${targetId}&csrf_token=<?php echo get_csrf_token(); ?>`
     })
     .then(response => response.json())
     .then(data => {
